var languageNames = {
"en-US": "Engelsk (USA)",
"am": "Amharisk",
"ar": "Arabisk",
"ast": "Asturisk",
"bg": "Bulgarsk",
"bn": "Bengalsk",
"bn-IN": "Bengalsk (India)",
"bo": "Tibetansk",
"bs": "Bosnisk",
"ca": "Katalansk",
"ca-valencia": "Valenciansk katalansk",
"cs": "Tjekkisk",
"da": "Dansk",
"de": "Tysk",
"dz": "Dzongkha",
"el": "Gresk",
"en-GB": "Engelsk (UK)",
"en-ZA": "Engelsk (SA)",
"eo": "Esperanto",
"es": "Spansk",
"et": "Estisk",
"eu": "Baskisk",
"fi": "Finsk",
"fr": "Fransk",
"gl": "Galisisk",
"gu": "Gujarati",
"he": "Hebraisk",
"hi": "Hindi",
"hr": "Kroatisk",
"hu": "Ungarsk",
"id": "Indonesisk",
"is": "Islandsk",
"it": "Italiensk",
"ja": "Japansk",
"ka": "Georgisk",
"km": "Khmer",
"ko": "Koreansk",
"lo": "Laotisk",
"lt": "Litauisk",
"lv": "Latvisk",
"mk": "Makedonsk",
"nb": "Norsk bokmål",
"ne": "Nepalesisk",
"nl": "Nederlandsk",
"nn": "Norsk nynorsk",
"om": "Oromo",
"pl": "Polsk",
"pt": "Portugisisk",
"pt-BR": "Brasiliansk portugisisk",
"ro": "Rumensk",
"ru": "Russisk",
"si": "Singalesisk",
"sid": "Sidama",
"sk": "Slovakisk",
"sl": "Slovensk",
"sq": "Albansk",
"sv": "Svensk",
"ta": "Tamilsk",
"tg": "Tadsjikisk",
"tr": "Tyrkisk",
"ug": "Uigurisk",
"uk": "Ukrainsk",
"vi": "Vietnamesisk",
"zh-CN": "Kinesisk (forenkla)",
"zh-TW": "Kinesisk (tradisjonell)",
};
